@@ -120,6 +120,7 @@ def add_images_to_existing_project(session, projnumber):
         moving_images = [i for i in existing_project['children']
                          if "MovingImage" in i["name"]]
         num_existing_moving = 0
+        moving_folder = None
         if moving_images is not None and len(moving_images) > 0:
             moving_folder = moving_images[0]
             num_existing_moving = len(moving_folder["children"])
@@ -200,9 +201,9 @@ def add_images_to_existing_project(session, projnumber):
         num_moving = num_existing_moving + additional_moving
         for i in range(num_existing_moving, num_existing_moving + additional_moving):
             shot = shotnumber_to_letter(i)
-            print(f"📸 MovingImage {shot} for {moving_artist['username']}")
             moving_shot_name = f"{projnumber}_MovingImage_{shot}"
-            moving_shot = session.create("Image", {
+            print(f"📸 MovingImage {moving_shot_name} for {moving_artist['username']}")
+            moving_shot = session.create("Movingimage", {
                 "name": moving_shot_name,
                 "parent": moving_folder}
             )
